[glib] gfile: Don't use C++ keyword "template" as variable name
- From: Colin Walters <walters src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [glib] gfile: Don't use C++ keyword "template" as variable name
- Date: Fri, 9 Dec 2011 16:14:28 +0000 (UTC)
commit 4eeac41d7dd9b75d2d44f5542f70d4f795a34333
Author: Colin Walters <walters verbum org>
Date: Fri Dec 9 11:13:23 2011 -0500
gfile: Don't use C++ keyword "template" as variable name
This breaks autotestkeyword.cc from gtk+.
gio/gfile.c | 8 ++++----
gio/gfile.h | 2 +-
2 files changed, 5 insertions(+), 5 deletions(-)
---
diff --git a/gio/gfile.h b/gio/gfile.h
index 0638f23..ea156d1 100644
--- a/gio/gfile.h
+++ b/gio/gfile.h
@@ -550,7 +550,7 @@ GType g_file_get_type (void) G_GNUC_CONST;
GFile * g_file_new_for_path (const char *path);
GFile * g_file_new_for_uri (const char *uri);
GFile * g_file_new_for_commandline_arg (const char *arg);
-GFile * g_file_new_tmp (const char *template,
+GFile * g_file_new_tmp (const char *tmpl,
GFileIOStream **iostream,
GError **error);
GFile * g_file_parse_name (const char *parse_name);
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/gio/gfile.c b/gio/gfile.c
index eac2eaf..171cc3f 100644
--- a/gio/gfile.c
+++ b/gio/gfile.c
@@ -5895,7 +5895,7 @@ g_file_new_for_uri (const char *uri)
/**
* g_file_new_tmp:
* @template: (type filename) (allow-none): Template for the file
* name, as in g_file_open_tmp(), or %NULL for a default template.
* @iostream: (out): on return, a #GFileIOStream for the created file.
* @error: a #GError, or %NULL
@@ -5915,7 +5915,7 @@ g_file_new_for_uri (const char *uri)
* Free the returned object with g_object_unref().
**/
GFile *
-g_file_new_tmp (const char *template,
+g_file_new_tmp (const char *tmpl,
GFileIOStream **iostream,
GError **error)
{
@@ -5924,10 +5924,10 @@ g_file_new_tmp (const char *template,
GFile *file;
GFileOutputStream *output;
- g_return_val_if_fail (template != NULL, NULL);
+ g_return_val_if_fail (tmpl != NULL, NULL);
g_return_val_if_fail (iostream != NULL, NULL);
- fd = g_file_open_tmp (template, &path, error);
+ fd = g_file_open_tmp (tmpl, &path, error);
if (fd == -1)
return NULL;
@@ -5895,7 +5895,7 @@ g_file_new_for_uri (const char *uri)
/**
* g_file_new_tmp:
- * @template: (type filename) (allow-none): Template for the file
+ * @tmpl: (type filename) (allow-none): Template for the file
* name, as in g_file_open_tmp(), or %NULL for a default template.
* @iostream: (out): on return, a #GFileIOStream for the created file.